@@ -58,10 +58,6 @@ def collect_participants(
     Returns the list of participants to be finally processed.
     Requesting all subjects in a BIDS directory root:
 
-    .. testsetup::
-
-        >>> data_dir_canary()
-
     Examples
     --------
     >>> collect_participants(str(datadir / 'ds114'), bids_validate=False)
@@ -157,10 +153,6 @@ def collect_data(
     """
     Uses pybids to retrieve the input data for a given participant
 
-    .. testsetup::
-
-        >>> data_dir_canary()
-
     Examples
     --------
     >>> bids_root, _ = collect_data(str(datadir / 'ds054'), '100185',
@@ -200,11 +192,11 @@ def collect_data(
 
     queries = {
         "fmap": {"datatype": "fmap"},
-        "bold": {"datatype": "func", "suffix": "bold", "part": ["mag", None]},
-        "sbref": {"datatype": "func", "suffix": "sbref", "part": ["mag", None]},
-        "flair": {"datatype": "anat", "suffix": "FLAIR", "part": ["mag", None]},
-        "t2w": {"datatype": "anat", "suffix": "T2w", "part": ["mag", None]},
-        "t1w": {"datatype": "anat", "suffix": "T1w", "part": ["mag", None]},
+        "bold": {"datatype": "func", "suffix": "bold"},
+        "sbref": {"datatype": "func", "suffix": "sbref"},
+        "flair": {"datatype": "anat", "suffix": "FLAIR"},
+        "t2w": {"datatype": "anat", "suffix": "T2w"},
+        "t1w": {"datatype": "anat", "suffix": "T1w"},
         "roi": {"datatype": "anat", "suffix": "roi"},
     }
     bids_filters = bids_filters or {}
@@ -240,10 +232,6 @@ def get_metadata_for_nifti(in_file, bids_dir=None, validate=True):
     """
     Fetch metadata for a given NIfTI file.
 
-    .. testsetup::
-
-        >>> data_dir_canary()
-
     Examples
     --------
     >>> metadata = get_metadata_for_nifti(
